@@ -5,8 +5,10 @@ use warnings;
 
 use CLI::Helpers qw(:all);
 use File::Basename;
+use File::Spec;
 use Config::GitLike;
 use Git::Code::Review::Utilities qw(:all);
+use Git::Code::Review::Utilities::Date qw(days_age load_special_days special_age weekdays_age);
 use Git::Code::Review::Notify qw(notify);
 use Git::Code::Review -command;
 use POSIX qw(strftime);
@@ -16,7 +18,9 @@ use Time::Local;
 my $default_age = 2;
 sub opt_spec {
     return (
-           ['age|days:i', "Age of commits in days to consider overdue default: $default_age", { default => $default_age } ],
+           ['age|days:i', "Age of commits in days to consider overdue. Default: $default_age", { default => $default_age } ],
+           ['weekdays',   "Exclude weekend days in age calculations. Default: false / off", { default => 0 } ],
+           ['workdays',   "Exclude weekend and special days specified in .code-review/special-days.txt from age calculations. Default: false / off", { default => 0 } ],
            ['critical',   "Set high priority and enable acrimonious excess in verbage." ],
            ['all',        "Run report for all profiles." ],
     );
@@ -35,17 +39,30 @@ sub execute {
     my($cmd,$opt,$args) = @_;
 
     die "Not initialized, run git-code-review init!" unless gcr_is_initialized();
+    die "You can use weekdays or workdays, but not both!" if $opt->{weekdays} && $opt->{workdays};
     gcr_reset();
 
     my $profile = gcr_profile();
     my $audit   = gcr_repo();
 
+    my ($days_str, $days_old) = $opt->{weekdays} ? ( 'weekdays', \&weekdays_age ) : ( 'days', \&days_age );
+    if ( $opt->{workdays} ) {
+        # load special days to exclude from .code-review/special-days.txt
+        # this location was chosen instead of passing it as a parameter so that changes to the
+        # special-days.txt would leave an audit trail
+        my $holidays_file = File::Spec->catfile(gcr_dir(),'.code-review',"special-days.txt");
+        load_special_days( $holidays_file ) if -f $holidays_file;
+        verbose({color=>'yellow'}, sprintf "Will exclude %d special days from workday age calculations",
+            scalar @{ load_special_days() }
+        );
+        ($days_str, $days_old) = ( 'workdays', \&special_age );
+    }
     my @ls = ( 'ls-files' );
     push @ls, $opt->{all} ? '**.patch' : sprintf('%s/**.patch', $profile);
 
     # Look for commits that aren't approved and older than X days
     my @overdue = sort { $a->{select_date} cmp $b->{select_date} }
-                    grep { days_old($_->{select_date}) >= $opt->{age} }
+                    grep { $days_old->($_->{select_date}) >= $opt->{age} }
                     map { $_=gcr_commit_info(basename $_) }
                     grep !/Approved/, $audit->run(@ls);
 
@@ -112,9 +129,9 @@ sub execute {
         }
 
         # Grab contact information
-        foreach my $profile (keys %profiles) {
+        foreach my $p (keys %profiles) {
             my @configs = (
-                File::Spec->catfile(gcr_dir(),'.code-review','profiles',$profile,'notification.config'),
+                File::Spec->catfile(gcr_dir(),'.code-review','profiles',$p,'notification.config'),
                 File::Spec->catfile(gcr_dir(),'.code-review','notification.config')
             );
             my %c = ();
@@ -126,55 +143,58 @@ sub execute {
                     1;
                 };
                 next unless $rc == 1;
+                # Remove the ignored profiles
+                die "ignore.overdue setting is invalid. Use true/false, 1/0 or yes/no only." if exists $config->{ 'ignore.overdue' } && $config->{ 'ignore.overdue' } !~ m/^\s*(?:1|0|true|false|yes|no)\s*$/i;
+                if ( ( $config->{ 'ignore.overdue' } || '' ) =~ m/^\s*(?:1|true|yes)\s*$/i ) {
+                    # ignore it if configured to ignore unless it was specifically requested
+                    if ( $opt->{all} || $p ne $profile ) {
+                        output({color=>'yellow'}, "Ignoring profile $p");
+                        delete $profiles{ $p };
+                        next;
+                    } else {
+                        output({color=>'yellow'}, "Ignored profile $p was explicitly requested, so ignoring the ignore setting");
+                    }
+                }
                 next unless exists $config->{'template.select.to'};
                 $c{$_} = 1 for (ref $config->{'template.select.to'} eq 'ARRAY' ? @{ $config->{'template.select.to'} }
                                                                                : $config->{'template.select.to'}
                 );
             }
-            $contacts{$profile} = scalar(keys %c) ? [ sort keys %c ] : [qw(NONE)];
+            $contacts{$p} = scalar(keys %c) ? [ sort keys %c ] : [qw(NONE)];
         }
-        output({color=>'cyan',clear=>1},
-            '=*'x40,
-            sprintf("Overdue commits (older than %d days)", $opt->{age}),
-            '=*'x40,
-        );
-        notify(overdue => {
-            priority => exists $opt->{critical} ? 'high' : 'normal',
-            options  => $opt,
-            profiles => \%profiles,
-            concerns => \%concerns,
-            contacts => \%contacts,
-        });
-    }
-    else {
+        my $total = 0;
+        $total += $profiles{$_}->{total} for keys %profiles;
+        if ( $total ) {
+            output({color=>'cyan',clear=>1},
+                '=*'x40,
+                sprintf("Overdue commits (older than %d days)", $opt->{age}),
+                '=*'x40,
+            );
+            notify(overdue => {
+                priority => exists $opt->{critical} ? 'high' : 'normal',
+                options  => $opt,
+                profiles => \%profiles,
+                concerns => \%concerns,
+                contacts => \%contacts,
+            });
+        } else {
+            my $p = $opt->{all} ? 'ALL' : $profile;
+            output({color=>'green'}, sprintf "All commits %d days old and older have been reviewed in (not ignored) profile: %s",
+                $opt->{age},
+                $p
+            );
+        }
+    } else {
         my $p = $opt->{all} ? 'ALL' : $profile;
-        output({color=>'green'}, sprintf "All commits %d days old and older have been reviewed in profile: %s",
+        output({color=>'green'}, sprintf "All commits %d %s old and older have been reviewed in profile: %s",
             $opt->{age},
+            $days_str,
             $p
         );
     }
 
 }
 
-my $NOW = timelocal(0,0,0,(localtime)[3,4,5]);
-my %_Ages = ();
-sub days_old {
-    my ($date) = @_;
-
-    return $_Ages{$date} if exists $_Ages{$date};
-
-    # Get Y, M, D parts.
-    my @parts = reverse split '-', $date;
-    # Decrement Month
-    $parts[1]--;
-
-    my $epoch = timelocal(0,0,0,@parts);
-    my $diff  = $NOW - $epoch;
-    my $days_old = int($diff / 86400);
-
-    return $_Ages{$date} = $days_old;
-}
-
 1;
 
 __END__
@@ -189,7 +209,7 @@ Git::Code::Review::Command::overdue - Report overdue commits
 
 =head1 VERSION
 
-version 2.1
+version 2.2
 
 =head1 AUTHOR
 
