@@ -162,6 +162,9 @@ sub _default_file {
             '[global]',
             "  from = $CFG{user}",
             '',
+            ';[ignore]',
+            ';  overdue = no',
+            '',
             ';[template "select"]',
             ";  to = $CFG{user}",
         ],
@@ -192,7 +195,7 @@ Git::Code::Review::Command::profile - Manage profiles for the code selection
 
 =head1 VERSION
 
-version 2.1
+version 2.2
 
 =head1 AUTHOR
 
