@@ -159,7 +159,7 @@ sub execute {
             my $fh = IO::File->new();
             if( $fh->open($file,"w") ) {
                 # Add the content
-                print $fh "$_\n" for $source->run(show => $sha1, '-w', '--date=iso', '--pretty=fuller');
+                print $fh "$_\n" for $source->run(show => $sha1, '-w', '--date=iso', '--pretty=fuller', '--find-renames');
                 verbose("+ Added $file to the Audit.");
                 close $fh;
                 # remove the absolute path pieces
@@ -254,7 +254,7 @@ Git::Code::Review::Command::select - Perform commit selection
 
 =head1 VERSION
 
-version 2.1
+version 2.2
 
 =head1 AUTHOR
 
