@@ -3,7 +3,7 @@ package Git::Code::Review::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '2.1'; # VERSION
+our $VERSION = '2.2'; # VERSION
 
 # Utility Modules
 use CLI::Helpers qw(:all);
@@ -86,7 +86,7 @@ my %CFG = (
     editor => exists $ENV{EDITOR} && exists $EDITOR{$ENV{EDITOR}} ? $ENV{EDITOR} : 'vim',
 );
 my %PATHS   = (
-    audit  => getcwd(),
+    audit  => $AUDITDIR,
     source => File::Spec->catdir($AUDITDIR,'source'),
 );
 my %ORIGINS = ();
@@ -578,7 +578,7 @@ sub gcr_commit_message {
         context => {
             pid      => $$,
             hostname => hostname(),
-            pwd      => getcwd,
+            pwd      => $AUDITDIR,
         },
     );
     my %cfg = gcr_config();
@@ -832,7 +832,7 @@ Git::Code::Review::Utilities - Tools for performing code review using Git as the
 
 =head1 VERSION
 
-version 2.1
+version 2.2
 
 =head1 FUNCTIONS
 
